@@ -30,7 +30,7 @@ __author__ = "Michael Imelfort"
 __copyright__ = "Copyright 2014"
 __credits__ = ["Michael Imelfort"]
 __license__ = "GPLv3"
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 __maintainer__ = "Michael Imelfort"
 __email__ = "mike@mikeimelfort.com"
 __status__ = "Dev"
@@ -45,7 +45,7 @@ import sqlite3 as lite
 
 # local imports
 from dancingPeasant.exceptions import *
-from dancinPeasant.baseFile import BaseFile
+from dancingPeasant.baseFile import BaseFile
 
 ###############################################################################
 ###############################################################################
@@ -55,18 +55,73 @@ from dancinPeasant.baseFile import BaseFile
 class Interface():
     """Class for implementing an interface to a SQL database"""
     def __init__(self, dbFileName, verbosity=0):
+        """self.db is set to None
+         The class that inherits this MUST set the db to their particular type
+        """
         self.dbFileName = dbFileName
-        self.baseFile = BaseFile(verbosity=verbosity)
+        self.connected = False
+        self.db = None
+
+#------------------------------------------------------------------------------
+# HOUSEKEEPING
+
+    def connect(self, createDB=False):
+        """connect to the BaseFile
+        if createDB is True the DB will be created if it doesn't exist
+
+        returns True if the DB was created
+        """
+        created = False
+        if self.db is None:
+            raise DP_UnsetDBException("Can not connect to DB until self.db is set to the inheriting Class")
+        try:
+            self.db.openFile(self.dbFileName)
+        except DP_FileNotFoundException:
+            # the DB could not be found
+            if createDB:
+                # we will make it
+                self.db.createNewFile(self.dbFileName)
+                created = True
+            else:
+                # pass the error on
+                raise
+        # we now have a connection to an open TrackM DB
+        self.connected = True
+        return created
+
+    def disconnect(self):
+        """close the baseFile"""
+        if self.connected:
+            self.db.closeFile()
 
 #------------------------------------------------------------------------------
 # SQL WRAPPERS
 
-    def simpleSelect(self,
-                     columns,           # select these columns
-                     table,             # from this table
-                     condition=None,    # where these conditions are met
-                     order=None         # order = ('col', ['ASC', 'DESC' or None])
-                     ):
+    def insert(self,
+               table,       # into this table
+               columns,     # these columns
+               values       # list of tuples of values
+               ):
+        """Speedy import of bulk data into SQL
+
+        table: is a single string. EX: 'bob'
+        cols: is an ordered list of column names in the table ['col1', 'col2', ... ]is a list of columns to insert into
+        vals is a list of tuples of values to insert
+
+        the ordering of cols and vals should make sense
+        vals should be quoted strings
+        """
+        insert_str = "INSERT INTO %s (%s) VALUES (%s);" % (table, ", ".join(columns), ", ".join(["?" for i in columns]))
+        cur = self.db.getCursor()
+        cur.executemany(insert_str, values)
+        self.db.commit()
+
+    def select(self,
+               table,             # from this table
+               columns,           # select these columns
+               condition=None,    # where these conditions are met
+               order=None         # order = ('col', ['ASC', 'DESC' or None])
+               ):
         """ wrap select statements comming in from the outside world
 
         columns: is an ordered list of column names in the table ['col1', 'col2', ... ] or ['*'] for all
@@ -76,12 +131,23 @@ class Interface():
             "type='big' or color='red'"
 
         Note: the use of single quotes on the values. This is important.
-        order is a string which dictates the ordering of the results. EX: 'col, asc'
+
+        order: is a tuple which dictates the ordering of the results. EX: ('col', 'ASC')
 
         This function is a generator of rows.
 
         """
-        pass
+        select_str = "SELECT %s FROM %s" % (", ".join(columns), table)
+        if condition is not None:
+            select_str += " WHERE %s" % condition
+        if order is not None:
+            select_str += " ORDER BY %s %s" % (order[0], order[1])
+
+        #print select_str
+
+        cur = self.db.getCursor()
+        cur.execute(select_str)
+        return cur.fetchall()
 
 ###############################################################################
 ###############################################################################
